package com.cmvr.device.service;

import java.util.List;
import com.cmvr.device.domain.DeRobotConfig;

/**
 * 机器人配置Service接口
 * 
 * @author cmvr-iot
 * @date 2025-09-09
 */
public interface IDeRobotConfigService 
{
    /**
     * 查询机器人配置
     * 
     * @param id 机器人配置主键
     * @return 机器人配置
     */
    public DeRobotConfig selectDeRobotConfigById(String id);

    /**
     * 查询机器人配置列表
     * 
     * @param deRobotConfig 机器人配置
     * @return 机器人配置集合
     */
    public List<DeRobotConfig> selectDeRobotConfigList(DeRobotConfig deRobotConfig);

    /**
     * 新增机器人配置
     * 
     * @param deRobotConfig 机器人配置
     * @return 结果
     */
    public int insertDeRobotConfig(DeRobotConfig deRobotConfig);

    /**
     * 修改机器人配置
     * 
     * @param deRobotConfig 机器人配置
     * @return 结果
     */
    public int updateDeRobotConfig(DeRobotConfig deRobotConfig);

    /**
     * 批量删除机器人配置
     * 
     * @param ids 需要删除的机器人配置主键集合
     * @return 结果
     */
    public int deleteDeRobotConfigByIds(String[] ids);

    /**
     * 删除机器人配置信息
     * 
     * @param id 机器人配置主键
     * @return 结果
     */
    public int deleteDeRobotConfigById(String id);
}
